@@ -16,7 +16,7 @@
 #ifndef RADIUSD_H
 #define RADIUSD_H
 /**
- * $Id: 028202fe2cc8eff66a5b1a126b17aeac7b496b86 $
+ * $Id: c3e8cdd142ad2b74729e92b9b907afe3f545b578 $
  *
  * @file radiusd.h
  * @brief Structures, prototypes and global variables for the FreeRADIUS server.
@@ -24,7 +24,7 @@
  * @copyright 1999-2000,2002-2008  The FreeRADIUS server project
  */
 
-RCSIDH(radiusd_h, "$Id: 028202fe2cc8eff66a5b1a126b17aeac7b496b86 $")
+RCSIDH(radiusd_h, "$Id: c3e8cdd142ad2b74729e92b9b907afe3f545b578 $")
 
 #include <freeradius/libradius.h>
 #include <freeradius/radpaths.h>
@@ -141,6 +141,8 @@ typedef struct main_config {
 	uint32_t	cleanup_delay;			//!< How long before cleaning up cached responses.
 	uint32_t	max_requests;
 
+	bool		postauth_client_lost;		//!< Whether to run Post-Auth-Type Client-Lost section
+
 	uint32_t	debug_level;
 	char const	*log_file;
 	int		syslog_facility;
@@ -275,6 +277,8 @@ struct rad_request {
 
 	RAD_LISTEN_TYPE		priority;
 
+	bool			max_time;	//!< did we hit max time?
+
 	bool			in_request_hash;
 #ifdef WITH_PROXY
 	bool			in_proxy_hash;
@@ -376,8 +380,8 @@ int		rad_accounting(REQUEST *);
 int		rad_coa_recv(REQUEST *request);
 
 /* session.c */
-int		rad_check_ts(uint32_t nasaddr, uint32_t nas_port, char const *user, char const *sessionid);
-int		session_zap(REQUEST *request, uint32_t nasaddr,
+int		rad_check_ts(fr_ipaddr_t const *nas_addr, uint32_t nas_port, char const *user, char const *sessionid);
+int		session_zap(REQUEST *request, fr_ipaddr_t const *nas_addr,
 			    uint32_t nas_port, char const *user,
 			    char const *sessionid, uint32_t cliaddr,
 			    char proto, int session_time);
@@ -585,7 +589,7 @@ void radius_event_free(void);
 int radius_event_process(void);
 void radius_update_listener(rad_listen_t *listener);
 void revive_home_server(void *ctx);
-void mark_home_server_dead(home_server_t *home, struct timeval *when);
+void mark_home_server_dead(home_server_t *home, struct timeval *when, bool down);
 
 /* evaluate.c */
 typedef struct fr_cond_t fr_cond_t;
@@ -605,6 +609,13 @@ int dual_tls_recv(rad_listen_t *listener);
 int dual_tls_send(rad_listen_t *listener, REQUEST *request);
 int proxy_tls_recv(rad_listen_t *listener);
 int proxy_tls_send(rad_listen_t *listener, REQUEST *request);
+#ifdef WITH_COA_TUNNEL
+int proxy_tls_send_reply(rad_listen_t *listener, REQUEST *request);
+int dual_tls_send_coa_request(rad_listen_t *listener, REQUEST *request);
+void listen_coa_free(void);
+void listen_coa_add(rad_listen_t *listener, char const *key);
+int listen_coa_find(REQUEST *request, char const *key);
+#endif
 #endif
 
 /*
